@@ -38,25 +38,41 @@ class ImageUtilsRawTestCase(test_base.BaseTestCase):
                                     exp_virtual_size=67108844)),
         ('64M_byte', dict(virtual_size='67108844',
                           exp_virtual_size=67108844)),
+        ('64_MiB_with_byte_hint', dict(virtual_size='64 MiB (67108844 bytes)',
+                                       exp_virtual_size=67108844)),
         ('4.4M', dict(virtual_size='4.4M',
                       exp_virtual_size=4613735)),
         ('4.4M_with_byte_hint', dict(virtual_size='4.4M (4592640 bytes)',
                                      exp_virtual_size=4592640)),
+        ('4.4_MiB_with_byte_hint', dict(virtual_size='4.4 MiB (4592640 bytes)',
+                                        exp_virtual_size=4592640)),
         ('2K', dict(virtual_size='2K',
                     exp_virtual_size=2048)),
         ('2K_with_byte_hint', dict(virtual_size='2K (2048 bytes)',
                                    exp_virtual_size=2048)),
+        ('2_KiB_with_byte_hint', dict(virtual_size='2 KiB (2048 bytes)',
+                                      exp_virtual_size=2048)),
+        ('1e+03_MiB', dict(virtual_size='1e+03 MiB',
+                           exp_virtual_size=1048576000)),
     ]
 
     _disk_size = [
         ('96K', dict(disk_size='96K',
                      exp_disk_size=98304)),
+        ('96_KiB', dict(disk_size='96 KiB',
+                        exp_disk_size=98304)),
         ('96K_byte', dict(disk_size='98304',
                           exp_disk_size=98304)),
+        ('98304_B', dict(disk_size='98304 B',
+                         exp_disk_size=98304)),
         ('3.1G', dict(disk_size='3.1G',
                       exp_disk_size=3328599655)),
+        ('3.1_GiB', dict(disk_size='3.1 GiB',
+                         exp_disk_size=3328599655)),
         ('unavailable', dict(disk_size='unavailable',
                              exp_disk_size=0)),
+        ('1e+03_MiB', dict(disk_size='1e+03 MiB',
+                           exp_disk_size=1048576000)),
     ]
 
     _garbage_before_snapshot = [
@@ -121,6 +137,7 @@ class ImageUtilsRawTestCase(test_base.BaseTestCase):
         image_info = imageutils.QemuImgInfo(example_output)
         self._base_validation(image_info)
 
+
 ImageUtilsRawTestCase.generate_scenarios()
 
 
@@ -187,6 +204,7 @@ class ImageUtilsQemuTestCase(ImageUtilsRawTestCase):
         if self.encrypted is not None:
             self.assertEqual(image_info.encrypted, self.encrypted)
 
+
 ImageUtilsQemuTestCase.generate_scenarios()
 
 
@@ -208,7 +226,8 @@ class ImageUtilsJSONTestCase(test_base.BaseTestCase):
                        "filename": "fake_img",
                        "cluster-size": 65536,
                        "format": "qcow2",
-                       "actual-size": 13168640
+                       "actual-size": 13168640,
+                       "format-specific": {"data": {"foo": "bar"}}
                       }'''
         image_info = imageutils.QemuImgInfo(img_output, format='json')
         self.assertEqual(41126400, image_info.virtual_size)
@@ -216,6 +235,7 @@ class ImageUtilsJSONTestCase(test_base.BaseTestCase):
         self.assertEqual(65536, image_info.cluster_size)
         self.assertEqual('qcow2', image_info.file_format)
         self.assertEqual(13168640, image_info.disk_size)
+        self.assertEqual("bar", image_info.format_specific["data"]["foo"])
 
     def test_qemu_img_info_json_format_blank(self):
         img_output = '{}'
@@ -225,3 +245,4 @@ class ImageUtilsJSONTestCase(test_base.BaseTestCase):
         self.assertIsNone(image_info.cluster_size)
         self.assertIsNone(image_info.file_format)
         self.assertIsNone(image_info.disk_size)
+        self.assertIsNone(image_info.format_specific)
